@@ -57,11 +57,13 @@ static void fill_mip_v4(struct ip_mreq *mip, apr_sockaddr_t *mcast,
     }
 }
 
-#if APR_HAVE_IPV6
+/* This function is only interested in AF_INET6 sockets, so a noop
+ * "return 0" implementation for the !APR_HAVE_IPV6 build is
+ * sufficient. */
 static unsigned int find_if_index(const apr_sockaddr_t *iface)
 {
     unsigned int index = 0;
-#ifdef HAVE_GETIFADDRS
+#if defined(HAVE_GETIFADDRS) && APR_HAVE_IPV6 
     struct ifaddrs *ifp, *ifs;
 
     /**
@@ -92,6 +94,7 @@ static unsigned int find_if_index(const apr_sockaddr_t *iface)
     return index;
 }
 
+#if APR_HAVE_IPV6
 static void fill_mip_v6(struct ipv6_mreq *mip, const apr_sockaddr_t *mcast,
                         const apr_sockaddr_t *iface)
 {
@@ -203,7 +206,7 @@ static apr_status_t do_mcast(int type, apr_socket_t *sock,
             fill_mip_v6(&mip6, mcast, iface);
 
             if (setsockopt(sock->socketdes, IPPROTO_IPV6, type,
-                           &mip6, sizeof(mip6)) == -1) {
+                           (const void *) &mip6, sizeof(mip6)) == -1) {
                 rv = errno;
             }
         }
@@ -237,7 +240,7 @@ static apr_status_t do_mcast_opt(int type, apr_socket_t *sock,
         unsigned int loopopt = value;
         type = IPV6_MULTICAST_LOOP;
         if (setsockopt(sock->socketdes, IPPROTO_IPV6, type,
-                       &loopopt, sizeof(loopopt)) == -1) {
+                       (const void *) &loopopt, sizeof(loopopt)) == -1) {
             rv = errno;
         }
     }
@@ -323,7 +326,7 @@ APR_DECLARE(apr_status_t) apr_mcast_interface(apr_socket_t *sock,
     else if (sock_is_ipv6(sock)) {
         unsigned int idx = find_if_index(iface);
         if (setsockopt(sock->socketdes, IPPROTO_IPV6, IPV6_MULTICAST_IF,
-                       &idx, sizeof(idx)) == -1) {
+                       (const void *) &idx, sizeof(idx)) == -1) {
             rv = errno;
         }
     }
